//=========================================================================
//
//	FILE:				Printing_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_Printing demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 6 $
//						Latest Checkout:  $Date: 2005-09-05 19:24:50 -0700 (Mon, 05 Sep 2005) $
//
//=========================================================================

	// CP_Printing
#include "Printing_App.h"
#include "Printing_View.h"

	// CPLAT_Framework
#include "CP_Application.tmpl.h"
#include "CP_Exceptions.h"
#include "CP_New.h"
#include "CP_PrintView.h"
#include "CP_Scroller.h"
#include "CP_String.h"
#include "CP_Types.h"
#include "CP_View.h"
#include "CP_Window.h"

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	Printing_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
Printing_Application::Printing_Application()
	: fPrintingWindow(NULL), fPrintingView1(NULL), fPrintingView2(NULL), fPrintingView3(NULL)
{
HandleOpenApplication();
}

//=========================================================================
//	FUNCTION:	~Printing_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
Printing_Application::~Printing_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === AboutBox ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String Printing_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to demonstrate printing.";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Commands ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. We take this opportunity to
*	create our initial window and views. In this demo, we create a few views
*	to draw into for printing.
*	
*	@exception	none
*
*	@return		void
*/
void Printing_Application::HandleOpenApplication()
{
	try
	{
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 612, 720 );
		CPLAT::CP_String				windowTitle( "Printing Test" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		
		fPrintingWindow = CP_new CPLAT::CP_Window();
		fPrintingWindow->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( fPrintingWindow );
		
		CPLAT::CP_Point					paneLocation( 50, 50 );
		CPLAT::CP_Size					paneSize( 100, 100 );

		paneLocation.Set( 50, 50 );
		paneSize.Set( 100, 24 );
		fPrintingView1 = CP_new Printing_View( fPrintingWindow, paneLocation, paneSize );

		paneLocation.Set( 200, 300 );
		paneSize.Set( 300, 200 );
		fPrintingView2 = CP_new Printing_View( fPrintingWindow, paneLocation, paneSize );

		paneLocation.Set( 50, 650 );
		paneSize.Set( 100, 24 );
		fPrintingView3 = CP_new Printing_View( fPrintingWindow, paneLocation, paneSize );

		GetPrintPolicy().SetParentWindow( fPrintingWindow );
		
		fPrintingWindow->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Printing ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandlePrinting
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Routine called from the printing policy to setup the views to be printed.
*
*	@param		inPrinter			The object that is controlling the printing,
*									and contains information about the page size,
*									and other printing parameters.
*	
*	@exception	none
*
*	@return		void
*/
void Printing_Application::HandlePrinting( CPLAT::CP_Printer *inPrinter )
{
	if( inPrinter != NULL )
	{
			// get the page size of our printout
		CPLAT::CP_Rect					pageArea = inPrinter->GetDefaultPrinterPageFormat().GetPageRect();
		CPLAT::CP_Point					topLeftPoint( pageArea.Left(), pageArea.Top() );
		CPLAT::CP_Size					contentSize = pageArea.Size();
		CPLAT::CP_Size					bottomRight( 0, 0 );
		CPLAT::CP_PrintView				*printView = CP_new CPLAT::CP_PrintView( topLeftPoint, contentSize );
	
		topLeftPoint.Set( 50, 50 );
		contentSize.Set( 100, 24 );
		bottomRight.Set( 150, 74 );
		printView->AddPrintingView( fPrintingView1, topLeftPoint, bottomRight );
		
		topLeftPoint.Set( 200, 300 );
		contentSize.Set( 300, 200 );
		bottomRight.Set( 500, 500 );
		printView->AddPrintingView( fPrintingView2, topLeftPoint, bottomRight );

		topLeftPoint.Set( 50, 650 );
		contentSize.Set( 100, 24 );
		bottomRight.Set( 200, 675 );
		printView->AddPrintingView( fPrintingView3, topLeftPoint, bottomRight );

		printView->DoPrint( inPrinter, fPrintingWindow );
	}
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
