//=========================================================================
//
//	FILE:				Threads_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the Threads demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 6 $
//						Latest Checkout:  $Date: 2005-09-05 19:25:56 -0700 (Mon, 05 Sep 2005) $
//
//=========================================================================

	// Threads
#include "Threads_App.h"
#include "Threads_RectsView.h"

	// CPLAT_Framework
#include "CP_Application.tmpl.h"
#include "CP_Data_ResourceTypes.h"
#include "CP_WindowManager.h"

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	CP_Threads_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_Threads_Application::CP_Threads_Application()
{
}

//=========================================================================
//	FUNCTION:	~CP_Threads_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_Threads_Application::~CP_Threads_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === AboutBox ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String CP_Threads_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to demonstrate CPLAT threads";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Commands ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleNewCommand
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Override the New command handler to create new windows. Since this application
*	is using a NULL document policy, we don't normally have the New menu item
*	enabled.
*
*	@return		inOutStatus			Return the OSStatus of this operation here.
*	@return		inCommandNo			The command being executed, in this case
*									CP_CMD_New/
*	
*	@exception	none
*
*	@return		void
*/
void CP_Threads_Application::HandleNewCommand( CPLAT::OSStatus& inOutStatus,
	CPLAT::CP_CommandNo& inCommandNo )
{
	CPLAT::OSStatus			status = CP_noErr;
	
	HandleOpenApplication();

	inOutStatus = status;
}

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. We take this opportunity to
*	create our initial window and views. In this demo, we create a window
*	that displays various rects in it.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Threads_Application::HandleOpenApplication()
{
	try
	{
		CPLAT::CP_Point						upperLeft( 50, 50 );
		CPLAT::CP_Size						contentSize( 500, 500 );
		CPLAT::CP_String					windowTitle( CP_T("Threads Demo") );
		CPLAT::CP_DocumentWindowType		documentWindowType;
		CPLAT::CP_Window					*threadsWindow = NULL;
		
		threadsWindow = CP_new CPLAT::CP_Window();
		threadsWindow->Create( upperLeft, contentSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( threadsWindow );

		CPLAT::CP_WindowManager::Instance()->Reposition( threadsWindow, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		threadsWindow->Show();

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 500, 500 );
		Threads_RectsView				*rectView = NULL;
		
		rectView = CP_new Threads_RectsView( threadsWindow, viewLocation, viewSize );
		rectView->SetupThread();		// initialize thread
	}
	catch(...)
	{
	}
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
