//=========================================================================
//
//	FILE:				CP_Application.tmpl.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Templete instatiation of the CP_Application class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 209 $
//						Latest Checkout:  $Date: 2005-06-10 17:22:36 -0700 (Fri, 10 Jun 2005) $
//
//=========================================================================
#ifndef _H_CP_Application_tmpl
#define _H_CP_Application_tmpl
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_AboutBox.h"
#include "CP_Application.h"
#include "CP_Debugging.h"
#include "CP_ErrorManager.h"
#include "CP_FrameworkResources.h"
#include "CP_MenuBarManager.h"
#include "CP_Messages.h"


#include "CP_SignalSlot.h"

CPLAT_Begin_Namespace_CPLAT

#if TARGET_CC_METROWERKS
#pragma mark === Construction / Destruction ==
#endif

//=========================================================================
//	FUNCTION:	CP_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::CP_Application()
{
	fAppStatus = kCP_E_AppStatus_Startup;
	
	CP_RegisterCommand( CP_CMD_About, CP_Command::CP_E_CH_AlwaysEnable)->connect( CP_SigSlot::slot(this, &CP_Application::HandleAboutBoxCommand) );

		// setup the printing slot to be called when/if the user requests
		// to print a document.
	fPrintSignal.connect( CP_SigSlot::slot( this, &CP_Application::HandlePrinting) );
}

//=========================================================================
//	FUNCTION:	~CP_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::~CP_Application() throw()
{
	fPrintPolicy.Cleanup();
}

#if TARGET_CC_METROWERKS
#pragma mark === Commands ==
#endif

//=========================================================================
//	FUNCTION:	HandleNewUpdateCommandStatusCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleNewUpdateCommandStatusCommand(
	CP_CommandStatus& inOutCommandStatus, bool& inOutWasHandled, CP_CommandNo& inCommandNo )
{
	fDocumentPolicy.HandleNewUpdateCommandStatusCommand( inOutCommandStatus, inOutWasHandled, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandleNewCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleNewCommand( OSStatus& inOutStatus,
	CP_CommandNo& inCommandNo )
{
	fDocumentPolicy.HandleNewCommand( inOutStatus, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandleOpenUpdateCommandStatusCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleOpenUpdateCommandStatusCommand(
	CP_CommandStatus& inOutCommandStatus, bool& inOutWasHandled, CP_CommandNo& inCommandNo )
{
	fDocumentPolicy.HandleOpenUpdateCommandStatusCommand( inOutCommandStatus, inOutWasHandled, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandleOpenCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleOpenCommand( OSStatus& inOutStatus,
	CP_CommandNo& inCommandNo )
{
	fDocumentPolicy.HandleOpenCommand( inOutStatus, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandlePageSetupUpdateCommandStatusCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandlePageSetupUpdateCommandStatusCommand(
	CP_CommandStatus& inOutCommandStatus, bool& inOutWasHandled, CP_CommandNo& inCommandNo )
{
	fPrintPolicy.HandlePageSetupUpdateCommandStatusCommand( inOutCommandStatus, inOutWasHandled, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandlePageSetupCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandlePageSetupCommand( OSStatus& inOutStatus,
	CP_CommandNo& inCommandNo )
{
	fPrintPolicy.HandlePageSetupCommand( inOutStatus, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandlePrintUpdateCommandStatusCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandlePrintUpdateCommandStatusCommand(
	CP_CommandStatus& inOutCommandStatus, bool& inOutWasHandled, CP_CommandNo& inCommandNo )
{
	fPrintPolicy.HandlePrintUpdateCommandStatusCommand( inOutCommandStatus, inOutWasHandled, inCommandNo );
}

//=========================================================================
//	FUNCTION:	HandlePrintCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandlePrintCommand( OSStatus& inOutStatus,
	CP_CommandNo& inCommandNo )
{
	fPrintPolicy.HandlePrintCommand( inOutStatus, inCommandNo, &fPrintSignal );
}

//=========================================================================
//	FUNCTION:	HandleAboutBoxCommand
//	
//	VISIBLITY:	Protected
//=========================================================================
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleAboutBoxCommand( OSStatus& /*inOutStatus*/,
	CP_CommandNo& /*inCommandNo*/ )
{
	CP_AboutBox::Instance()->SetOwnerApp( this );
	CP_AboutBox::Instance()->Display( GetAboutBoxDescription() );
}

#if TARGET_CC_METROWERKS
#pragma mark === Documents ==
#endif

//=========================================================================
//	FUNCTION:	CountDocuments
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Returns the nnumber of documents maanaged by this applicationn.
*	
*	@exception	none
*	
*	@return		SInt32				Returns the nnumber of documents.
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
SInt32 CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::CountDocuments()
{
	return( fDocumentPolicy.CountDocuments() );
}

//=========================================================================
//	FUNCTION:	GetNthDocument
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Returns the nth document created by this application, if the application
*	supports documents.
*	
*	@exception	none
*	
*	@return		CP_ScriptableObject_Imp	*	The returned document.
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
CP_ScriptableObject_Imp *CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::GetNthDocument( SInt32 inPosition )
{
	return( fDocumentPolicy.GetNthDocument( inPosition ) );
}

#if TARGET_CC_METROWERKS
#pragma mark === Events ==
#endif

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. This calls upon the document
*	policy to do any processing appropriate when the application opens up.
*	
*	@exception	none
*	
*	@return		void
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleOpenApplication()
{
	fDocumentPolicy.OnOpenApplication();
}

//=========================================================================
//	FUNCTION:	HandleQuitApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is quitting. This calls upon the document
*	policy to do any processing appropriate before the application quits.
*	
*	@exception	none
*	
*	@return		void
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
bool CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleQuitApplication()
{
	return( fDocumentPolicy.HandleQuitCommand() );
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === AppleEvents ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleOpenDocumentAppleEvent
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Handles the open document Apple Event. This calls on the document policy
*	to handle the event.
*
*	@param		inEvent				The Apple Event object that describes the incoming
*									event.
*	@param		inOutReply			An Apple Event object to return any reply in.
*	@param		inRefCon			Not used.
*	
*	@exception	none
*
*	@return		void
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
void CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::HandleOpenDocumentAppleEvent(
	const AppleEvent& inEvent, AppleEvent& inOutReply, SInt32 /*inRefCon*/ )
{
	fDocumentPolicy.HandleOpenDocumentAppleEvent( inEvent, inOutReply );
}

//=========================================================================
//	FUNCTION:	DoAE_CreateElement
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Called when we receive a create element AppleEvent. We will ask the document
*	policy to handle the creation of any new documents if supported by the policy.
*
*	@param 		inDesiredClass		A DescType describing the class desired to create.
*	@param 		inInsertLocation	A DescType describing the location to insert the object.
*	@param 		inEvent				The incoming AppleEvent that we are creating the
*									object for.
*	@param 		inOutAEReply		The reply to the incoming Apple Event.
*	
*	@exception	none
*
*	@return		CP_ScriptableObject_Imp *	The newly created element.
*/
template <class DOC_POLICY, class PRINT_POLICY, class UNDO_POLICY>
CP_ScriptableObject_Imp *CP_Application<DOC_POLICY, PRINT_POLICY, UNDO_POLICY>::DoAE_CreateElement(
	DescType inDesiredClass, DescType inInsertLocation, const AppleEvent& inEvent,
	AppleEvent& inOutAEReply )
{
	CP_ScriptableObject_Imp			*returnObject = NULL;
	
	returnObject = fDocumentPolicy.DoAE_CreateElement( inDesiredClass, inInsertLocation,
		inEvent, inOutAEReply );

	return( returnObject );
}

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Application_tmpl

