//=========================================================================
//
//	FILE:				CP_FTPResponse.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Base class to handle responses from our FTP servers.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				According to RFC 959:
//							A reply may either be 1 line of the form "abc ..." or
//							a reply may occupy several lines in which case it would
//							look like
//								abc-...
//								...
//								abc...
//							and the intermediate lines may start with abc or not.
//
//	VERSION:			Current Revision: $Rev: 22 $
//						Latest Checkout:  $Date: 2004-12-28 19:35:48 -0800 (Tue, 28 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_FTPResponse
#define _H_CP_FTPResponse
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_InternetResponse.h"
#include "CP_Socket.h"
#include "CP_String.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

	// FTP status code length
const size_t kCP_FTP_STATUS_CODE_LENGTH					= 3;

/*!
*	@class		CP_FTPResponse
*	@brief		 A CP_InternetResponse class to manage responses from an FTP server and the CP_FTP class.
*/
class CP_EXPORT CP_FTPResponse : public CP_InternetResponse
{
public:
	/*! Various response codes returned from the FTP server. */
	enum
	{
		kCP_FTP__DataConOpen		= 125,
		kCP_FTP__AboutToOpen		= 150,
		kCP_FTP__CommandOK			= 200,
		kCP_FTP__CmdNotImp			= 202,
		kCP_FTP__NameSystem			= 215,
		kCP_FTP__ServiceReady		= 220,
		kCP_FTP__ServiceClosing		= 221,
		kCP_FTP__ClosingDataCon		= 226,
		kCP_FTP__EnteringPsv		= 227,
		kCP_FTP__UserLoggedIn		= 230,
		kCP_FTP__FileActionOK		= 250,
		kCP_FTP__PathCreated		= 257,
		kCP_FTP__UserNameOK			= 331,
		kCP_FTP__ReqOKPending		= 350,
		kCP_FTP__ConnectionClosed	= 426,
		kCP_FTP__SyntaxErr			= 500,
		kCP_FTP__PermissionDenied	= 553
	};

	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_FTPResponse( CP_Socket *inSocket );
										CP_FTPResponse( const CP_FTPResponse& inResponse );
	//! Destructor.
	virtual								~CP_FTPResponse() throw();
	//@}
				
	//! @name Resonse
	//@{
	virtual		bool					GetServerResponse();
	//@}

protected:
	
private:

	// class data
protected:

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_FTPResponse


