//=========================================================================
//
//	FILE:				CP_OSPicture.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class for dealing with the native picture format on each
//						supported platform.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_OSPicture
#define _H_CP_OSPicture
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_NoCopy.h"
#include "CP_Rect.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_OSPicture
*	@brief		Class for dealing with the native picture format on each supported platform.
*/
class CP_EXPORT CP_OSPicture : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_OSPicture();
										CP_OSPicture( SInt16 inPictID );
	//! Destructor.
	virtual								~CP_OSPicture() throw();
	//@}
		
	//! @name Getters
	//@{
			CP_Rect						Bounds() const;
			UInt32						Width() const;
			UInt32						Height() const;

			OSPicture					GetOSPicture()										{ return( fPicture ); }
	//@}

	//! @name Drawing
	//@{
			void						Draw(
												CP_Canvas& inDestCanvas,
												const CP_Rect& inBounds );
	//@}

protected:

	// class data
protected:
	OSPicture							fPicture;		/* ! The underlying OSs picture object. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
private:
			void						SetupBitmap( SInt16 inPictureID );
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_OSPicture

