//=========================================================================
//
//	FILE:				CP_Printer.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class for management of the underlying OSs printing.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 162 $
//						Latest Checkout:  $Date: 2005-04-28 15:05:07 -0700 (Thu, 28 Apr 2005) $
//
//=========================================================================
#ifndef _H_CP_Printer
#define _H_CP_Printer
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_NoCopy.h"
#include "CP_Printer_PageFormat.h"
#include "CP_Rect.h"
#include "CP_SignalSlot.h"
#include "CP_Types.h"
#include "CP_Window.h"

CPLAT_Begin_Namespace_CPLAT

//!  CP_Printer
/*!
  class that wraps the functionality of printing on each of our platforms into a
  CPLAT object. This class deals with the interaction between CPLAT and the platforms
  printing manager. 
*/

	// forward class declarations
class CP_Printer;

typedef CP_SigSlot::CP_Signal1<CP_Printer *>				CP_PrintSignal;

class CP_EXPORT CP_Printer : public CP_NoCopy
{
public:
										CP_Printer();
	virtual								~CP_Printer();
	
											// Getters
				CP_Size					GetPrintAreaOffset();

				UInt32					GetNumberCopies();
				UInt32					GetFirstPage();
				UInt32					GetLastPage();
											
				CP_Printer_PageFormat	GetDefaultPrinterPageFormat();
				CP_PrintSignal			*GetPrintSignal()									{ return( fPrintSignal ); }

											// printing dialogs
				bool					DoPageSetup( CP_Window *inParentWindow = NULL );
				bool					DoPrintDialog(
												CP_PrintSignal *inPrintSignal,
												CP_Window *inParentWindow = NULL );
				
				bool					HasPrintRecord();

											// Document handling
				bool					OpenDocument();
				void					CloseDocument();
				
											// Page handling
				bool					OpenPage( CP_Printer_PageFormat& inOutPageFormat );
				bool					ClosePage();
				
											// Utility
				void					EndPrinting();

				bool					OpenPrinter();
				bool					ClosePrinter();
				

	// class data
protected:	
	CP_PrintSignal						*fPrintSignal;

	#if TARGET_OS_MAC
		PMPrintSession					fPrintSession;
		PMPageFormat					fDefaultPageFormat;
		PMPrintSettings					fPrintSettings;
		CGrafPtr						fPrintingPort;
		CGContextRef					fPrintingContextRef;
		
		bool							fUseQuartz;
			
		SInt16							fPrinterResFile;

		static CP_Printer				*fCurrentPrinter;
	#endif

	#if TARGET_OS_WIN32
		PAGESETUPDLG					fPrintRecord;
		PRINTDLG						fPrintPage;
		HDC								fPrinterPort;
		RECT							fPageRect;
		LPDEVMODE						flpDevMode;
	#endif

	#if TARGET_OS_LINUX
		OSGraphicsPort					fPrinterPort;
	#endif

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
		PMPrintSession					GetPrintSession()							{ return( fPrintSession ); }
		PMPageFormat					GetDefaultPageFormat();
		PMPrintSettings					GetPrinterSettings()						{ return( fPrintSettings ); }

		CGrafPtr						GetPrinterPort()							{ return( fPrintingPort ); }

			// Quartz printer context
		CGContextRef					GetPrinterContextRef()						{ return( fPrintingContextRef ); }

		bool							UseQuartz()									{ return( fUseQuartz ); }
		void							SetUseQuartz( bool inUseQuartz )			{ fUseQuartz = inUseQuartz; }

private:
		OSStatus						CreateSheetDoneProcs();

		void							SetPrinter( CP_Printer *inPrinter )			{ fCurrentPrinter = inPrinter; }
		static CP_Printer				*GetPrinter()								{ return( fCurrentPrinter ); }

		static pascal void				CP_PageSetupDoneProc(
												PMPrintSession printSession,
												WindowRef documentWindow,
												Boolean accepted );
		static pascal void				CP_PrintDialogDoneProc(
												PMPrintSession printSession,
												WindowRef documentWindow,
												Boolean accepted );

#endif

#if TARGET_OS_WIN32
public:
		HDC								GetPrinterPort()							{ return( fPrinterPort ); }
#endif

#if TARGET_OS_LINUX
public:
		OSGraphicsPort					GetPrinterPort()							{ return( fPrinterPort ); }
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_Printer

