//=========================================================================
//
//	FILE:				CP_Size.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to handle specifying a size (width and height)
//						using floating point coordinates.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Size
#define _H_CP_Size
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Size
*	@brief		A class for representing a size using floating point coordinates.
*	
*				This class is used to express all sizes in CPLAT.
*
*				A size represents a measurement of both width and height.
*/
class CP_EXPORT CP_Size
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Size();
										CP_Size(
												float inWidth,
												float inHeight );
										CP_Size( const CP_Size& inFloatSize );
	//! Destructor.
										~CP_Size();
	//@}
				
	//! @name Getters
	//@{
										/*!
										*	Return the width data member.
										*
										*	@exception	none
										*	
										*	@return		float const		Width of this object.
										*/
			float						Width() const										{ return( fWidth ); }

										/*!
										*	Return the height data member.
										*
										*	@exception	none
										*	
										*	@return		float const		Height of this object.
										*/
			float						Height() const										{ return( fHeight ); }
	//@}

	//! @name Comparers
	//@{
			bool						operator == ( const CP_Size& inSize ) const;
			bool						operator != ( const CP_Size& inSize ) const;
			bool						operator >= ( const CP_Size& inSize ) const;
			bool						operator <= ( const CP_Size& inSize ) const;

			bool						operator > ( const CP_Size& inSize );
			bool						operator < ( const CP_Size& inSize );
	//@}
							
	//! @name Math
	//@{
			CP_Size&					operator += ( const CP_Size& inSize );
			CP_Size&					operator -= ( const CP_Size& inSize );
			CP_Size&					operator *= ( const CP_Size& inSize );
			CP_Size&					operator /= ( const CP_Size& inSize );

			CP_Size						operator + ( const CP_Size& inSize ) const;
			CP_Size						operator - ( const CP_Size& inSize ) const;
			CP_Size						operator * ( const CP_Size& inSize ) const;
			CP_Size						operator / ( const CP_Size& inSize ) const;

			CP_Size&					operator = ( const CP_Size& );

			CP_Size						operator -() const;
	//@}
			
	//! @name Setters
	//@{
			void						SetWidth( float inWidth )							{ fWidth = inWidth; }
			void						SetHeight( float inHeight )							{ fHeight = inHeight; }
			void						Set(
											float inWidth,
											float inHeight );
	//@}

protected:

	// class data
public:
	float								fWidth;			/*! Width measurement. */
	float								fHeight;		/*! height measurement. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
	#if UNIVERSAL_INTERFACES_VERSION >= 0x0400
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Size( HISize inSize );
	//@}

	//! @name Converters
	//@{
										operator HISize *();
										operator const HISize *() const;
										operator const HISize () const;

			CP_Size&					operator = ( HISize inSize );
	//@}
	#endif	// UNIVERSAL_INTERFACES_VERSION >= 0x0400
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Size
