//=========================================================================
//
//	FILE:				CP_PtrBlockStream.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CPLAT streaming class for reading and writing streamed
//						data to a CP_PtrBlock object.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_PtrBlockStream
#define _H_CP_PtrBlockStream
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_InStream.h"
#include "CP_OutStream.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

// class forward declarations
class CP_EXPORT CP_PtrBlock;

/*!
*	\class		CP_PtrBlockOutstream
*	\brief		CP_OutStream class for writing data to a CP_PtrBlock object.
*/
class CP_EXPORT CP_PtrBlockOutStream : public CP_OutStream
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_PtrBlockOutStream(
												CP_PtrBlock *inOutBlock,
												bool inHasHeader = true );
										CP_PtrBlockOutStream(
												CP_PtrBlock *inOutBlock,
												UInt32 inBeginPosition,
												bool inHasHeader = true );
	//! Destructor.
	virtual								~CP_PtrBlockOutStream() throw();
	//@}
												
	//! @name PtrBlock
	//@{	
			CP_PtrBlock					*GetPtrBlock() const;
			void						SetPtrBlock( CP_PtrBlock *inPtrBlock );
	//@}
			
	//! @name Positioning
	//@{
	virtual UInt32						GetPosition() const;
	virtual	void						SetPosition( UInt32 inPosition );
	//@}

protected:
	//! @name Positioning
	//@{
	virtual void 						OnWriteBytes(
												const void *inDestBuffer,
												UInt32 inNumberBytes );
	virtual	UInt32						OnWriteData(
												const void *inBuffer,
												UInt32 inBytesToWrite );
	//@}

private:
	//! @name PtrBlock
	//@{
			void						GrowPtrBlock( UInt32 inNewSizeNeeded );
	//@}

protected:
	CP_PtrBlock							*fPtrBlock;		/*! The CP_PtrBlock object we are writing to. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

/*!
*	\class		CP_PtrBlockInstream
*	\brief		CP_OutStream class for reading data from a CP_PtrBlock object.
*/
class CP_EXPORT CP_PtrBlockInStream : public CP_InStream
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_PtrBlockInStream(
												const CP_PtrBlock *inBlock,
												bool inHasHeader = true );
										CP_PtrBlockInStream(
												const CP_PtrBlock *inBlock,
												UInt32 inBeginPosition,
												bool inHasHeader = true );
	//! Destructor.
	virtual								~CP_PtrBlockInStream() throw();
	//@}

	//! @name Getters
	//@{
	virtual UInt32						GetLength() const;
	//@}

	//! @name PtrBlock
	//@{
			const CP_PtrBlock			*GetPtrBlock() const;
			void						SetPtrBlock( const CP_PtrBlock *inPtrBlock );
	//@}

	//! @name Positioners
	//@{
	virtual UInt32						GetPosition() const;
	virtual void						SetPosition( UInt32 inPosition );
	//@}

protected:
	//! @name Reading
	//@{
	virtual UInt32 						OnReadBytes(
												void *inDestBuffer,
												UInt32 inNumberBytes );
	//@}

protected:
 	const CP_PtrBlock					*fPtrBlock;			/*! The CP_PtrBlock object we are reading from. */
	UInt32								fCurrentPosition;	/*! The current marker in the handle block where the next read comes from. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_PtrBlockStream



