//=========================================================================
//
//	FILE:				CP_SocketOutStream.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to write stream data to socket connection.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_SocketOutStream
#define _H_CP_SocketOutStream
#ifndef __BUILD_LINUX__
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_OutStream.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_SocketOutStream
*	@brief		Class to write stream data to socket connection.
*/
class CP_EXPORT CP_SocketOutStream : public CP_OutStream
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SocketOutStream(
												class CP_Socket& inSocket,
												bool inHasHeader,
												bool inHasDebugTags = false );
	//! Destructor.
	virtual 							~CP_SocketOutStream () throw();
	//@}

	//! @name Misc
	//@{
	virtual void						Flush();
	virtual void						Close();
	//@}
	
protected:
	class CP_Socket& fSocket;

	//! @name Writing
	//@{
	virtual void						OnWriteBytes(
												const void *inBuffer,
												UInt32 inBytesToWrite );
	//@}
	
private:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SocketOutStream();
										CP_SocketOutStream( const CP_SocketOutStream& obj );
	//@}

	//! @name operators
	//@{
	CP_SocketOutStream& 				operator = ( const CP_SocketOutStream& obj );
	//@}
	
	// Make private, because GetPosition and SetPosition should not be called on a socket stream.
	//! @name Position
	//@{
	CP_OutStream::GetPosition;
	CP_OutStream::SetPosition;
	//@}

	// class data
protected:

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_SocketOutStream
