//=========================================================================
//
//	FILE:				CP_XMLAttributes.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class that represents the attributes for an XML
//						element.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 10 $
//						Latest Checkout:  $Date: 2004-12-24 14:46:10 -0800 (Fri, 24 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_XMLAttributes
#define _H_CP_XMLAttributes
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if defined(_MSC_VER)
	#pragma warning(disable : 4786)	
	#pragma warning(disable : 4138)	
#endif

	// CPLAT_Framework
#include "CP_String.h"

	// expat
#include <expat.h>

	// Standard Library
#include <map>

CPLAT_Begin_Namespace_CPLAT

#ifndef TARGET_OS_LINUX
	typedef std::map<CP_String, CP_String, std::less<CP_String> >				CP_Attribute_List;
	typedef std::map<CP_String, CP_String, std::less<CP_String> >::iterator		CP_Attribute_Iterator;

	typedef std::pair<const CP_String, CP_String>								CP_Attribute_Entry;
#else
	typedef std::map<CP_String, CP_String, std::less<CP_String> >				CP_Attribute_List;
	typedef std::map<CP_String, CP_String, std::less<CP_String> >::iterator		CP_Attribute_Iterator;

	typedef std::pair<const CP_String, CP_String>								CP_Attribute_Entry;
#endif

	// routine to format our XML string data returned from the XML parser into
	// a user string that has all of the high character coding converted back to
	// its original value.
CP_String				XMLToCP_StringcharData(
								const XML_Char *s,
					 			SInt32 inLength );
CP_String				XMLToCP_StringcharData_private(
								const XML_Char *s,
					 			SInt32 inLength );

/*!
*	@class		CP_XMLAttributes
*	@brief		A class to handle xml element attributes.
*	
*				A class to handle getting the attributes from an XML stream. All of the
*				data passed to your object from the XML streams is passed as a list of CP_XMLAttributes.
*				To retrieve the data you need to ask the passed in attributes for the data that
*				corresponds to the tag contained in inAttributeName.
*
*	@ingroup	XML
*/
class CP_EXPORT CP_XMLAttributes
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_XMLAttributes();
										CP_XMLAttributes( const XML_Char **inAttributes );
	//@}
									
	//! @name Attribute List
	//@{
			bool						HasAttribute(const CP_String& inAttributeName) const;
			UInt32						GetCount();
			CP_String					GetNthAttribute( const SInt32 inIndex );

										/*!
										*	Returns the list of attributes.
										*	
										*	@exception	none
										*	
										*	@return		CP_Attribute_List		List of attributes.
										*/
			CP_Attribute_List			GetAttributeList()											{ return( fAttributes ); }
	//@}
			
	//! @name Attributes
	//@{
			bool						GetBoolValue( const CP_String& inAttributeName );
			CP_String					GetStringValue( const CP_String& inAttributeName );
			char						GetCharValue( const CP_String& inAttributeName );
			SInt16						GetSInt16Value( const CP_String& inAttributeName );
			UInt16						GetUInt16Value( const CP_String& inAttributeName );
			SInt32						GetSInt32Value( const CP_String& inAttributeName );
			UInt32						GetUInt32Value( const CP_String& inAttributeName );
			float						GetFloatValue( const CP_String& inAttributeName );
	//@}

	// class data members
protected:
	CP_Attribute_List					fAttributes;			/*! List of attributes. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_XMLAttributes( CFDictionaryRef inAttributes );
	//@}
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_XMLAttributes


