//=========================================================================
//
//	FILE:				CP_View_Imp_HIToolbar.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_Toolbar implementation object that uses the MacOS
//						HIToolbar to implmement the toolbar.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 267 $
//						Latest Checkout:  $Date: 2005-08-31 19:33:20 -0700 (Wed, 31 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_View_Imp_HIToolbar
#define _H_CP_View_Imp_HIToolbar
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_API_MAC_CARBON && TARGET_RT_MAC_MACHO && defined(MAC_OS_X_VERSION_10_2) && (MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_2)

	// CPLAT_Framework
#include "CP_Structure_Defines.h"
#include "CP_View_Imp_HIView.h"


#include "CP_SignalSlot.h"

CPLAT_Begin_Namespace_CPLAT

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === CP_View_Imp_HIToolbar ===
#pragma mark -
#endif

/*!
*	\class		CP_View_Imp_HIToolbar
*	\brief		CP_Toolbar implementation object that uses the MacOS HIToolbar to implmement the toolbar.
*/
class CP_EXPORT CP_View_Imp_HIToolbar : public CP_View_Imp_HIView
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_HIToolbar(
												CP_View_Imp *inOwnerViewImp,
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_View_Imp_HIToolbar() throw();
	//@}

	//! @name Delegate
	//@{
			OSStatus					ToolbarDelegateHandler(
												EventHandlerCallRef inCallRef,
												EventRef inEvent );
	//@}

	//! @name Toolbar Items
	//@{
			void						AddItem(
												const CP_String& inItemText,
												const CP_S_ViewContentInfo& inContentInfo,
												const CP_CommandNo inCommand,
												const CP_String& inHelpString,
												const CP_String& inSecondaryHelpString = "" );
	//@}

	//! @name Configuration
	//@{
	virtual	void						GetToolbarDefaultItems( CFMutableArrayRef inArray );
	virtual	void						GetToolbarAllowedItems( CFMutableArrayRef inArray );
	virtual	HIToolbarItemRef			CreateToolbarItemForIdentifier(
												CFStringRef inIdentifier,
												CFTypeRef inConfigData );
	//@}

protected:

private:
	//! @name Initialization
	//@{
			void						Init(
												CP_View *inSuperview,
												const CP_Point& inLocation,
												const CP_Size& inContentSize );
	//@}

	// class data
protected:
	HIToolbarRef						fHIToolbar;
};

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === CP_HIToolbarItem ===
#pragma mark -
#endif

/*!
*	\class		CP_HIToolbarItem
*	\brief		Class to represent a custom toolbar item used in the HIToolbar class.
*/
class CP_EXPORT CP_HIToolbarItem : public CP_SigSlot::CP_SlotObject
{
public:
		typedef ::OSStatus				(*ConstructProc)(
												HIObjectRef inBaseObject,
												CP_HIToolbarItem **outInstance );

	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_HIToolbarItem( HIObjectRef inObjectRef );
	//! Destructor.
	virtual								~CP_HIToolbarItem();
	//@}

	//! @name Registration
	//@{
	static void							RegisterCustomToolbarItemClass();
	//@}

	//! @name Construction
	//@{
	static HIToolbarItemRef				CreateCustomToolbarItem(
												const CP_String& inItemText,
												const CP_S_ViewContentInfo& inContentInfo,
												const CP_CommandNo inCommand );


		static ::OSStatus				Construct(
												HIObjectRef inObjectRef,
												CP_HIToolbarItem **ouCP_HIObject );

	//@}

	//! @name Events
	//@{
										/*!
										*	Return the event handler for this toolbar implementation.
										*	
										*	@exception	none
										*	
										*	@return		CP_EvnetHandler		The event handler for this toolbar.
										*/
	virtual	CP_EventHandler&			GetEventHandler()									{ return( fEventHandler ); }
	//@}

protected:
	//! @name Custom Items
	//@{
	virtual	void						DestructCustomToolbarItem();
	virtual	OSStatus					InitializeCustomToolbarItem( EventRef inEvent );
	virtual	CFTypeRef					CreateCustomToolbarItemPersistentData();
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

private:
	//! @name Events
	//@{
	static pascal ::OSStatus			CustomToolbarItemHandler( EventHandlerCallRef inCallRef, EventRef inEvent, void* inUserData );


											// Events
			void						HandlePerformActionEvent( CP_Event_Base& inEvent );
			void						HandlePersistEvent( CP_Event_Base& inEvent );
	//@}

	// Class data
protected:
	CP_String							fItemText;
	CP_S_ViewContentInfo				fContentInfo;
	CP_CommandNo						fCommand;

	HIToolbarItemRef					fToolbarItem;

	CP_EventHandler						fEventHandler;	/*! Class that handles all events. */
};

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === CP_HIToolbarItemData ===
#pragma mark -
#endif

// ===================================================================================
//	CP_HIToolbarItemData - structure containing the toolbars item data that is passed
//		in the toolbar item creation routines.
// ===================================================================================
struct CP_HIToolbarItemData
{
		// Class data
	CP_String							fItemText;
	CP_S_ViewContentInfo				fContentInfo;
	CP_CommandNo						fCommand;
	
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_HIToolbarItemData();
										CP_HIToolbarItemData( const CP_HIToolbarItemData& inItemData );
	//@}

	//! @name operators
	//@{
	CP_HIToolbarItemData&				operator =( const CP_HIToolbarItemData& inItemData );
	//@}
};

// ===================================================================================
//	CP_HIToolbarItemConfigData - structure used to create toolbar items when the toolbar
//		tries to create an item with an identifier.
// ===================================================================================
struct CP_HIToolbarItemConfigData
{
		// Class data
	CFStringRef							fIdentifier;
	CFTypeRef							fConfigData;
	HIToolbarItemRef					fReturnItem;
	
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_HIToolbarItemConfigData();
										CP_HIToolbarItemConfigData(
												CFStringRef inIdentifier,
												CFTypeRef inConfigData );
										CP_HIToolbarItemConfigData( const CP_HIToolbarItemConfigData& inItemData );
	//@}

	//! @name operators
	//@{
	CP_HIToolbarItemConfigData&			operator =( const CP_HIToolbarItemConfigData& inItemData );
	//@}
};

CPLAT_End_Namespace_CPLAT

#endif // TARGET_API_MAC_CARBON && TARGET_RT_MAC_MACHO && defined(MAC_OS_X_VERSION_10_2) && (MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_2)

#endif	// _H_CP_View_Imp_HIToolbar

