//=========================================================================
//
//	FILE:				CP_View_Imp_HIView.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CPLAT implementatio of HIView classes that interface
//						with the CP_HIView class and the CPLAT framework to provide
//						the base HIView support.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 251 $
//						Latest Checkout:  $Date: 2005-08-22 08:58:47 -0700 (Mon, 22 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_View_Imp_HIView
#define _H_CP_View_Imp_HIView
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC && TARGET_RT_MAC_MACHO && MAC_OS_X_VERSION_MAX_ALLOWED >= 1020

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_HIView.h"
#include "CP_Point.h"
#include "CP_Size.h"
#include "CP_View_Imp_Base.h"
#include "CP_OSStatus.h"
#include "CP_Region.h"
#include "CP_View.h"

CPLAT_Begin_Namespace_CPLAT

#if TARGET_CC_METROWERKS
#pragma mark === CP_View_Imp_HIView ==
#endif

/*!
*	@class		CP_View_Imp_HIView
*	@brief		Class to provide the CP_View implementation using HIViews.
*
*	@ingroup	UI
*/
class CP_View_Imp_HIView : public CP_View_Imp_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_HIView(
												CP_View_Imp *inOwnerViewImp,
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												bool inCreateImp = false );
	//! Destructor.
	virtual								~CP_View_Imp_HIView() throw();
	//@}

	//! @name Appearance
	//@{
	virtual	void						Show();
	virtual	void						Hide();

	virtual	void						Activate();
	virtual	void						Deactivate();

	virtual	void						Enable();
	virtual	void						Disable();
	//@}

	//! @name Getters
	//@{
	virtual	CP_EventHandler&			GetEventHandler();

			CP_HIView					*GetHIViewImp()										{ return( fHIViewImp ); }
	virtual	CP_Rect						GetPortBounds();
	//@}

	//! @name Drawing
	//@{
	virtual	CP_Canvas					SetupForDrawing();
	virtual	void						Draw();

			void						DrawContents( CP_Event_Base& inEvent );
	virtual	void						Refresh();
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );

			void						HandleHitTest( CP_Event_Base& inEvent );
			void						HandleTrack( CP_Event_Base& inEvent );

			void						HandleRawKeyDownEvent( CPLAT::CP_Event_Base& inEvent );

			void						HandleMouseMoved( CPLAT::CP_Event_Base& inEvent );
			void						HandleMouseEntered( CPLAT::CP_Event_Base& inEvent );
			void						HandleMouseExited( CPLAT::CP_Event_Base& inEvent );
	//@}

	//! @name Positioning
	//@{
	virtual	void						Move( const CP_Point& inOffset );
	//@}

	//! @name Setters
	//@{
			void						SetPortBounds( const CP_Rect& inBounds );
	virtual	void						SetBounds(
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	virtual	void						SetLocation( const CP_Point& inLocation );
	virtual	void						SetSize( const CP_Size& inSize );
	//@}

	//! @name Superview
	//@{
	virtual	void						AddSubview( CP_View_Imp *inView );
	//@}

	//! @name Testers
	//@{
	virtual	bool						IsVisible() const;
	virtual	bool						IsActive() const;
	virtual	bool						IsEnabled() const;
	//@}

protected:
	//! @name Drawing
	//@{
			void						Invalidate( const CP_Region& inInvalidArea );
	//@}

	// class data
protected:
	CP_HIView							*fHIViewImp;			/*! CP_HIView interface bwtween this class and the HIView support. */

	CP_EventHandler						fDummyEventHandler;
	
	bool								fIsFocused;
};

CPLAT_End_Namespace_CPLAT

#endif	//	TARGET_OS_MAC && TARGET_RT_MAC_MACHO && MAC_OS_X_VERSION_MAX_ALLOWED >= 1020

#endif	// _H_CP_View_Imp_HIView

