//=========================================================================
//
//	FILE:				CP_View_Imp_Toolbar.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			MacOS non HIToolbar implementation of the CP_Toolbar.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 267 $
//						Latest Checkout:  $Date: 2005-08-31 19:33:20 -0700 (Wed, 31 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_View_Imp_Toolbar
#define _H_CP_View_Imp_Toolbar
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
#include "CP_Structure_Defines.h"
#include "CP_View_Imp_Control.h"

CPLAT_Begin_Namespace_CPLAT

	// forward class declarations
class CP_View_Imp_Toolbar_Item;

typedef std::vector<CP_View_Imp_Toolbar_Item *, std::allocator<CP_View_Imp_Toolbar_Item *> >					CP_ToolbarItems_List;
typedef std::vector<CP_View_Imp_Toolbar_Item *, std::allocator<CP_View_Imp_Toolbar_Item *> >::iterator			CP_ToolbarItems_Iterator;

class CP_EXPORT CP_View_Imp_Toolbar : public CP_View_Imp_Control
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_Toolbar(
												CP_View_Imp *inOwnerViewImp,
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_View_Imp_Toolbar() throw();
	//@}

	//! @name Toolbar Items
	//@{
			void						AddItem(
												const CP_String& inItemText,
												const CP_S_ViewContentInfo& inContentInfo,
												const CP_CommandNo inCommand,
												const CP_String& inHelpString,
												const CP_String& inSecondaryHelpString = "" );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						HandleDrawInCanvas(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Misc
	//@{
			void						EmbedItemInToolbar( CP_View_Imp_Toolbar_Item *inItem );
			SInt16						GetNextItemHorPosition();
	//@}

	// class data
private:
	CP_ToolbarItems_List				fToolbarItems;
};

class CP_EXPORT CP_View_Imp_Toolbar_Item : public CP_View_Imp_Control
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_Toolbar_Item(
												CP_View_Imp *inOwnerViewImp,
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inItemText,
												const CP_S_ViewContentInfo& inContentInfo,
												const CP_CommandNo inCommand );
	//! Destructor.
	virtual								~CP_View_Imp_Toolbar_Item() throw();
	//@}

	//! @name Events
	//@{
	virtual	ControlPartCode				HandleHitTest(
												ControlRef inControl,
												const CP_Point& inMouseLocation );
	virtual	ControlPartCode				HandleTracking(
												ControlRef inControl,
												const CP_Point& inMouseLocation,
												ControlActionUPP inActionProc );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						HandleDrawInCanvas(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Getters
	//@{
			CP_Rect						GetTextBounds(
												const CP_Rect& inBounds,
												bool inLimitToTextWidth ) const;
			CP_Rect						GetImageBounds( const CP_Rect& inBounds ) const;
	//@}
			
	// class data
protected:
	CP_String							fItemText;
	CP_S_ViewContentInfo				fContentInfo;
	CP_CommandNo						fCommand;
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_MAC

#endif	// _H_CP_View_Imp_Toolbar

