//=========================================================================
//
//	FILE:				CP_CheckGroupBox.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms check box group box control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_CheckGroupBox
#define _H_CP_CheckGroupBox
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_CheckGroupBox
*	@brief		Implementation of a platforms text group box control that also displays a check box.
*
*				If the platform does not support a native check group box, it is implemented
*				using native OS theme elements.
*
*	@section 	persistance Persistance:
*				The following tags are implemented to create the button from
*				a persistance stream:
*					- kCP_Persist_ControlSignature - UInt32
*					- kCP_Persist_Bounds - CP_Rect
*					- kCP_Persist_Text - CP_String
*					- kCP_Persist_Command - UInt32
*					- kCP_Persist_IsHidden - bool
*					- kCP_Persist_IsEnabled - bool
*					- kCP_Persist_GroupBoxStyle - CP_E_GroupBoxStyle
*					- kCP_Persist_InitialValue - SInt32
*
*	@section 	signals Signals and Slots:
*				The following signals and slot are implemented in this class:
*					- None
*
*				From CP_PlatformControl:
*					- kCP_Signal_Clicked
*					- kCP_Signal_ValueChanged
*
*	@ingroup	UI
*/
class CP_EXPORT CP_CheckGroupBox : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_CheckGroupBox();
										CP_CheckGroupBox(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												CP_E_GroupBoxStyle inGroupBoxStyle = kCP_GroupBox_Primary );
	//! Destructor.
	virtual								~CP_CheckGroupBox() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
	//! @name Slots
	//@{
	virtual	void						HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

protected:
	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:

	#if TARGET_OS_WIN32 || TARGET_OS_LINUX
		CP_String						fText;				/*! Text displayed for the title of the popup. */
		CP_E_GroupBoxStyle 				fGroupBoxStyle;		/*! Type of group box - primary or secondary. */

		#if TARGET_OS_WIN32
			OSControl					fCheckBoxControl;

			CP_EventHandler				fCheckBoxEventHandler;		/*! Class that handles all of the events for this windnow. */

			WNDPROC						fnOldCheckBoxWndProc;
		#endif
	#endif
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												CP_E_GroupBoxStyle inGroupBoxStyle = kCP_GroupBox_Primary );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	virtual	LRESULT						HandleWinHelperProcMessage(
												HWND hwnd,
												UINT iMsg,
												WPARAM wParam,
												LPARAM lParam );


protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												CP_E_GroupBoxStyle inGroupBoxStyle = kCP_GroupBox_Primary );
	//@}
#endif

#if TARGET_OS_LINUX
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												CP_E_GroupBoxStyle inGroupBoxStyle = kCP_GroupBox_Primary );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_CheckGroupBox
