//=========================================================================
//
//	FILE:				CP_DrawerWindow.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_Window class to provide support for MacOS drawer windows.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_DrawerWindow
#define _H_CP_DrawerWindow
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Window.h"

CPLAT_Begin_Namespace_CPLAT

#if TARGET_OS_MAC && TARGET_RT_MAC_MACHO
	enum CP_E_DrawerEdge
	{
		CP_E_DrawerEdge_WindowEdgeDefault = kWindowEdgeDefault,
		CP_E_DrawerEdge_WindowEdgeTop = kWindowEdgeTop,
		CP_E_DrawerEdge_WindowEdgeLeft = kWindowEdgeLeft,
		CP_E_DrawerEdge_WindowEdgeBottom = kWindowEdgeBottom,
		CP_E_DrawerEdge_WindowEdgeRight = kWindowEdgeRight
	};
#else
	enum CP_E_DrawerEdge
	{
		CP_E_DrawerEdge_WindowEdgeDefault = 0,
		CP_E_DrawerEdge_WindowEdgeTop = 1 << 0,
		CP_E_DrawerEdge_WindowEdgeLeft = 1 << 1,
		CP_E_DrawerEdge_WindowEdgeBottom = 1 << 2,
		CP_E_DrawerEdge_WindowEdgeRight = 1 << 3
	};
#endif

/*!
*	\class		CP_DrawerWindow
*	\brief		1 LINE BRIEF DESCRIPTION HERE
*	
*				DETAILED DESCRIPTION BEGINS HERE
*/
class CP_EXPORT CP_DrawerWindow : public CP_Window
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_DrawerWindow( CP_Window *inParent );
	//! Destructor.
	virtual								~CP_DrawerWindow() throw();
	//@}
			
	//! @name Appearance
	//@{
	virtual	void						Show();
	virtual	void						Hide();
	
			void						Open( SInt16 inEdge = CP_E_DrawerEdge_WindowEdgeDefault );
			void						Close();

			void						Toggle();
	//@}

	//! @name Getters
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	//! @name Getters
			UInt32						GetPreferredEdge() const;
			UInt32						GetEdge() const;
			void						GetOffsets(
												float& outLeadingOffset,
												float& outTrailingOffset ) const;
	//@}

	//! @name Parent
			CP_Window					*GetParent()										{ return( fParentWindow ); }
			void						SetParent( CP_Window *inParent );
	//@}

	//! @name Setters
			void						SetPreferredEdge( UInt32 inEdge );
			void						SetOffsets(
												float inLeadingOffset,
												float inTrailingOffset ) const;
	//@}

	//! @name Testers
			bool						IsOpen();
	//@}

protected:

	// class data
protected:
	CP_Window							*fParentWindow;

		// Signals
	CP_DataValueSignal					fDrawerOpeningSignal;		/*! Signal sent when the window is opening. */
	CP_DataValueSignal					fDrawerOpenedSignal;		/*! Signal sent when the window has opened. */
	CP_DataValueSignal					fDrawerClosingSignal;		/*! Signal sent when the window is closing. */
	CP_DataValueSignal					fDrawerClosedSignal;		/*! Signal sent when the window has closed. */
		
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
			void						HandleDrawerOpeningEvent( CP_Event_Base& inEvent );
			void						HandleDrawerOpenedEvent( CP_Event_Base& inEvent );
			void						HandleDrawerClosingEvent( CP_Event_Base& inEvent );
			void						HandleDrawerClosedEvent( CP_Event_Base& inEvent );
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_DrawerWindow

