//=========================================================================
//
//	FILE:				CP_TV_DataBrowserRow.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to represent a single row in a CP_TableView object.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_TV_DataBrowserRow
#define _H_CP_TV_DataBrowserRow
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_NoCopy.h"
#include "CP_Rect.h"

CPLAT_Begin_Namespace_CPLAT

	// forward class declarations
class CP_TV_DataBrowser;

class CP_EXPORT CP_TV_DataBrowserRow : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowserRow(
												CP_TV_DataBrowser *inOwnerDataBrowser,
												UInt32 inID = 0 );
	//@}
	//! Destructor.
	virtual								~CP_TV_DataBrowserRow() throw();
	//@}
			
	//! @name Data
	//@{
			CP_S_TV_DB_CellData			GetCellData( SInt32 inCol );
			void						SetCellData(
												SInt32 inCol,
												CP_S_TV_DB_CellData& inCellData );
	//@}

	//! @name Drawing
	//@{
			void						Draw( CP_Canvas& inDestCanvas );
	//@}

	//! @name Editing
	//@{
			void						HandleContentHandlerEditing( SInt32 inColumn );
	//@}

	//! @name Events
	//@{
	virtual	void						HandleClick( const CP_Point& inMouseLocation );
	//@}

	//! @name Getters
	//@{
			CP_TV_DataBrowser			*GetOwnerDataBrowser()							{ return( fOwnerDataBrowser ); }

										/*!
										*	Returns the bounds of this row.
										*	
										*	@exception	none
										*	
										*	@return		CP_Rect const		Bounds of the row.
										*/
			CP_Rect						GetBounds() const								{ return( fRowBounds ); }
			CP_Rect						GetColBounds(
												SInt32 inRow,
												SInt32 inColumn ) const;

			SInt16						GetRowIndent()									{ return( fRowIndent ); }
			UInt32						GetFlags()										{ return( fRowFlags ); }
	//@}

	//! @name Identifier
	//@{
										/*!
										*	Returns the identifier of this row.
										*	
										*	@exception	none
										*	
										*	@return		UInt32 const		Identifier for this row.
										*/
			UInt32						GetID()	const									{ return( fID ); }

										/*!
										*	Sets the identifier of this row.
										*	
										*	@param		inID				Identifier for this row.
										*
										*	@exception	none
										*	
										*	@return		void
										*/
			void						SetID( UInt32 inID )							{ fID = inID; }
	//@}

	//! @name Parent / Child Rows
	//@{
											// Child
			bool						HasChildren() const;
			void						AddChild( CP_TV_DataBrowserRow *inChildRow );

			void						Expand();
			void						Collapse();

			bool						IsExpanded()									{ return( (bool) (fRowFlags & kCP_TV_DB_IsExpanded) ); }
			
			CP_Rows_Array				*GetChildRowList()								{ return( fChildRows ); }

			CP_TV_DataBrowserRow 		*FindRow( UInt32 inID );
	//@}

	//! @name Setters
	//@{
			void						SetBounds( const CP_Rect& inBounds );
			void						SetRowHeight( SInt32 inRowHeight );

			void						SetRowIndent( SInt16 inIndent )					{ fRowIndent = inIndent; }
			void						SetFlags( UInt32 inFlags )						{ fRowFlags = inFlags; }
	
			void						SetNumberColumns(
												SInt32 inRow,
												SInt32 inNumberCols );
	//@}
	
	virtual	void						HandleExpanding();
	virtual	void						HandleCollapsing();

protected:
	//! @name Disclosure
	//@{
	virtual	void						DrawDisclosure(
												CP_Canvas& inDestCanvas,
												const CP_Rect& inDisclosureBounds );

			CP_Rect						GetDisclosureBounds() const;
	//@}

			SInt32						GetColumn( const CP_Point& inMouseLocation );

	virtual	void						OnExpand();
	virtual	void						OnCollapse();

private:
	//! @name Events
	//@{
			bool						HandleClickInDisclosure( const CP_Point& inMouseLocation );
	//@}

	// class data
protected:
	CP_TV_DataBrowser					*fOwnerDataBrowser;		/*! The CP_TV_DataBrowser that contains this row */
	UInt32								fID;					/*! The identifier of this row */

	CP_DataBrowserCellData_Array		*fRowData;				/*! holds any user taged data for this row. */
	
	CP_Rows_Array						*fChildRows;			/*! List of child rows for this row. */

	CP_Rect								fRowBounds;				/*! The bounds of this row. */
	SInt16								fRowIndent;				/*! Distance to edge of first column. */
	UInt32								fRowFlags;				/*! Flags that control appearance of this row. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_TV_DataBrowserRow

