//=========================================================================
//
//	FILE:				CP_View_Imp.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			MacOS implementation of a CP_View.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 251 $
//						Latest Checkout:  $Date: 2005-08-22 08:58:47 -0700 (Mon, 22 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_View_Imp
#define _H_CP_View_Imp
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_Enums.h"
#include "CP_EventHandler.h"
#include "CP_FrameAdapter.h"
#include "CP_Point.h"
#include "CP_Size.h"
#include "CP_M_DragSource.h"
#include "CP_M_DragTarget.h"
#include "CP_M_Persist.h"
#include "CP_Region.h"
#include "CP_SignalSlot.h"
#include "CP_SmartPtr.h"
#include "CP_StPortSaver.h"
#include "CP_StClipSaver.h"
#include "CP_ViewBackground.h"
#include "CP_View_Imp_Base.h"

CPLAT_Begin_Namespace_CPLAT

	// forward class declaration
class CP_Window;

/*!
*	@class		CP_View_Imp
*	@brief		MacOS implementation of the CP_View class.
*
*				Under MacOS non HIView all panes are implmented in this class as MacOS
*				user pane controls.
*	
*				Under Windows all panes are implmented in this class as Windows child windows.
*
*	@ingroup UI
*/
class CP_EXPORT CP_View_Imp : public CP_M_Persist, public CP_M_CommandHandler, public CP_M_DragSource,
	public CP_M_DragTarget
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
	virtual								~CP_View_Imp() throw();
	//@}
			
	//! @name Appearance
	//@{
	virtual	void						Show();
	virtual	void						Hide();

	virtual	void						Activate();
	virtual	void						Deactivate();

	virtual	void						Enable();
	virtual	void						Disable();
	//@}

	//! @name Coordinates
	//@{
	virtual	void						GlobalToPort( CP_Point& inGlobalPoint );
	virtual	void						GlobalToLocal( CP_Point& inGlobalPoint );
			void						PortToLocal( CP_Point& inPortPoint );
	virtual	void						PortToGlobal( CP_Point& inPortPoint );
	virtual	void						PortToGlobal( CP_Rect& inPortRect );

			void						LocalToPort( CP_Point& inPortPoint );
			void						LocalToPort( CP_Rect& inPortRect );	
	//@}
	
	//! @name Data
	//@{
			void						GetData(
												UInt32 inTagName,
												SInt32 inDataSize,
												void *inData );
			void						SetData(
												UInt32 inTagName,
												SInt32 inDataSize,
												const void *inData );
	//@}
			
	//! @name Drag Drop
	//@{
	virtual	void						HandleDragReceive( CP_DragDrop& /*inDragDrop*/ )	{}
	//@}

	//! @name Getters
	//@{
	virtual	CP_EventHandler&			GetEventHandler();

	virtual	CP_Window					*GetContainingWindow();

			CP_View						*GetSuperview();
			CP_Rect						GetLocalBounds();
	virtual	CP_Rect						GetPortBounds();
	virtual	CP_Rect						GetContentBounds();
	virtual	CP_Point					GetLocation() const;
	virtual	CP_Size						GetSize() const;
	
			UInt32						GetCommandID()										{ return( fCommandID ); }
	//@}

	//! @name Drawing
	//@{
	virtual	CP_Canvas					SetupForDrawing();
			void						FinishDrawing( CP_Canvas& drawCanvas );
			void						HandleDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
												
			void						Invalidate( const CP_Region& inInvalidArea );
			void						Invalidate( const CP_Rect& inInvalidArea );
	virtual	void						Refresh();
	//@}

	//! @name Flags
	//@{
			UInt32						GetFlags()											{ return( fFlags ); }
			void						SetFlags( UInt32 inFlags )							{ fFlags = inFlags; }
	//@}


	//! @name Frame Adapter
	//@{
			void						SetFrameAdapter( CP_FrameAdapter *inAdapter );
	//@}

	//! @name Mouse Events
	//@{
	virtual	void						HandleMouseMoved(
												CP_Event_Base& /*inEvent*/,
												const CP_Point& /*inLocalMouseLocation*/ )	{}
	virtual	void						HandleMouseEntered( CP_Event_Base& /*inEvent*/ )	{}
	virtual	void						HandleMouseExited( CP_Event_Base& /*inEvent*/ )		{}
	//@}

	//! @name Setters
	//@{
			void						SetCommandID( UInt32 inCommandID );

	virtual	void						SetLocation( const CP_Point& inLocation );
	virtual	void						SetSize( const CP_Size& inSize );
	virtual	void						SetPortBounds( const CP_Rect& inBounds );
	//@}

	//! @name Signal / Slots
	//@{
			void						Show_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
			void						Hide_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
			void						Activate_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
			void						Deactivate_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
			void						Enable_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
			void						Disable_Slot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
	//@}

	//! @name Superview
	//@{
	virtual	void						AddSubview( CP_View *inView );
			void						AdjustToSuperview( CP_View *inView );
	//@}


	//! @name View Imp Base
	//@{
			void						SetViewImpBase( CP_View_Imp_Base *inViewImpBase );
			CP_View_Imp_Base			*GetViewImpBase()									{ return( fViewImpBase ); }
	//@}

	//! @name Testers
	//@{
	virtual	bool						IsVisible() const;
	virtual	bool						IsActive() const;
	virtual	bool						IsEnabled() const;

			bool						ContainsPoint( const CP_Point& inPortPoint );
	//@}

			CP_ViewBackground			*GetViewBackground();
			void						SetViewBackground( CP_ViewBackground *inViewBackground );

protected:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp();
										CP_View_Imp(
										CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												bool inCreateImp = false,
												UInt32 inFlags = CP_E_ViewFlags_None );
	//@}

	//! @name Initialization
	//@{
	virtual	void						CreateImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												bool inCreateImp = false );
	//@}	

	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}
			
	//! @name Drag and Drop
	//@{
	virtual	bool						OnCanAcceptDrag(
												UInt32 inItem,
												CPLAT::CP_DragDrop& inDragDrop );

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}
			
	//! @name Frame
	//@{
	virtual	void						HandleBoundsChanged(
												const CP_Rect& /*inPreviousBounds*/,
												const CP_Rect& /*inNewBounds*/ )			{}
	virtual	void						OnBoundsChanged(
												const CP_Rect& inPreviousBounds,
												const CP_Rect& inNewBounds );
	//@}

private:

	// class data
protected:
	CP_View_Imp_Base					*fViewImpBase;			/*! Object that actually implements the pane. */

	CP_EventHandler						fDummyEventHandler;		/*! Dummy event handler if the view imp has not been created. */

	UInt32								fCommandID;				/*! The command associated with this view / control. */
	
	CP_SmartPtr<CP_FrameAdapter>		fFrameAdapter;

	UInt32								fFlags;
	
	CP_ViewBackground					*fViewBackground;

		// Signals
	CP_DataValueSignal					fBoundsChangedSignal;	/*! Signal sent when the bounds of this view change. */

	CP_DataValueSignal					fShowSignal;			/*! Signal sent when the view is becoming visible. */
	CP_DataValueSignal					fHideSignal;			/*! Signal sent when the view is becoming hidden. */
	CP_DataValueSignal					fActivateSignal;		/*! Signal sent when the view is becoming active. */
	CP_DataValueSignal					fDeactivateSignal;		/*! Signal sent when the view is becoming inactive. */
	CP_DataValueSignal					fEnableSignal;			/*! Signal sent when the view is becoming enabled. */
	CP_DataValueSignal					fDisableSignal;			/*! Signal sent when the view is becoming disable. */

		// slots
	CP_DataValueSlot					fShowSlot;				/*! Slot to show a view. */
	CP_DataValueSlot					fHideSlot;				/*! Slot to hide a view. */
	CP_DataValueSlot					fActivateSlot;			/*! Slot to activate a view. */
	CP_DataValueSlot					fDeactivateSlot;		/*! Slot to deactivate a view. */
	CP_DataValueSlot					fEnableSlot;			/*! Slot to enable a view. */
	CP_DataValueSlot					fDisableSlot;			/*! Slot to disable a view. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Events
	//@{
	virtual	ControlPartCode				HandleHitTest( const CP_Point& inMouseLocation );
	virtual	ControlPartCode				HandleTracking(
												const CP_Point& inMouseLocation,
												ControlActionUPP actionProc );
	virtual	ControlPartCode				HandleFocus( ControlFocusPart inFocusPart );
	virtual	void						HandleActivate( Boolean inActivating );
	virtual	void						HandleKeyDown(
												SInt16 keyCode,
												SInt16 charCode,
												SInt16 modifiers );
	//@}

protected:	//! @name Drag Target
	//@{
	virtual WindowRef					GetDragWindow();
	virtual CPLAT::CP_Region 			GetDropRegion();
	virtual	bool						PtInDropArea( CPLAT::CP_Point& inGlobalPoint );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	virtual CP_RGBColor					GetBackColor();

protected:
	virtual	void						HandleControlColor( CP_Event_Base& inEvent );

#endif

#if TARGET_OS_LINUX
public:
	virtual	void						HandleMouseDown( CP_Event_Base& inEvent );
	virtual	void						HandleMouseUp( CP_Event_Base& inEvent );
#endif
};


#if TARGET_CC_METROWERKS
#pragma mark === CP_StSetupforDrawing ==
#endif

class CP_EXPORT CP_StSetupforDrawing
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
										CP_StSetupforDrawing( CP_View_Imp *inDestView );
	virtual								~CP_StSetupforDrawing() throw();
	//@}
	
			CP_Canvas					GetCanvas()									{ return( fViewCanvas ); }

	// class data
protected:
	CP_View_Imp							*fDestView;
	CP_Canvas							fViewCanvas;
	CP_StPortSaver						fSavedPort;
	CP_StClipSaver						fSavedClip;

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_View_Imp

