//=========================================================================
//
//	FILE:				CP_File_Imp_Win.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Windows implementation of the CP_File class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_File_Imp_Win
#define _H_CP_File_Imp_Win
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_Data_ResourceTypes.h"
#include "CP_Enums.h"
#include "CP_FileSystemSpec.h"
#include "CP_NoCopy.h"
#include "CP_OSTypes.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class	CP_File_Mac_Imp
*	@brief	Windows implementation of CP_File.
*/
class CP_EXPORT CP_File_Imp : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_File_Imp();
										CP_File_Imp( const CP_FileSystemSpec& inFileSpec );
	//! Destructor.
	virtual								~CP_File_Imp();
	//@}
			
	//! @name Creation
	//@{
			void						Create(
												FourCharCode inCreator,
												FourCharCode inType = kCP_Text_FileType );
	//@}

	//! @name Open / Close
	//@{
			void						Open( SInt32 inPermissions = CP_E_FilePerm_ReadWrite );
			void 						Close();
	//@}
						
			CP_FileSystemSpec			GetFileSpec()										{ return( fFileSpec ); }

	//! @name Length
	//@{
			SInt64						Length();
	//@}

	//! @name Position
	//@{
			SInt64						GetPosition() const;
			SInt64						SetPosition(
												UInt16 inMode,
												SInt64 inOffset );
			void 						SetEOF( SInt32 inEOF );
	//@}

	//! @name Read / Write
	//@{
			UInt32						ReadData(
												void *inDataBuffer,
												UInt32 inDataSize,
												UInt16 inPositionMode = CP_E_FileSeek_FromCurrent,
												SInt64 inOffset = 0 );
			UInt32						WriteData(
												const void *inDataBuffer,
												UInt32 inDataSize,
												UInt16 inPositionMode = CP_E_FileSeek_FromCurrent,
												SInt64 inOffset = 0 );
	//@}
									
	//! @name Setters
	//@{
			void						SetFileSpec( const CP_FileSystemSpec& inFileSpec )	{ fFileSpec = inFileSpec; }
	//@}

	//! @name Testers
	//@{
			bool						IsOpen()																{ return( fRefNum != kCP_BadFileRefNum ); }							
	//@}

protected:

	// class data
protected:
	CP_FileSystemSpec					fFileSpec;		/*! CP_FileSystemSpec containing the name and location of this file. */
	OSFileRef							fRefNum;		/*! Windows file reference number for file when open. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_win32

#endif	// _H_CP_File_Imp_Win

