//=========================================================================
//
//	FILE:				CP_ThemeSupport.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Classes and routines to draw various OS elements with
//						Windows theme support.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 183 $
//						Latest Checkout:  $Date: 2005-05-20 15:23:52 -0700 (Fri, 20 May 2005) $
//
//=========================================================================
#ifndef _H_CP_ThemeSupport
#define _H_CP_ThemeSupport
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32 && CP_Optional_ThemeSupport_Windows

	// CPLAT_Framework
#include "CP_Types.h"

	// Windows SDK
#include "uxtheme.h"
#include <tmschema.h>

CPLAT_Begin_Namespace_CPLAT

namespace CP_Theme
{

///////////////////////////////////////////////////////////////////////////////
//
// typedefs for uxtheme functions
//
typedef HRESULT	(__stdcall *PFNCLOSETHEMEDATA)(HTHEME hTheme);
typedef HRESULT	(__stdcall *PFNDRAWTHEMEBACKGROUND)(HTHEME hTheme, HDC hdc,
	int iPartId, int iStateId, const RECT *pRect,  const RECT *pClipRect);
typedef HRESULT	(__stdcall *PFNDRAWTHEMETEXT)(HTHEME hTheme, HDC hdc,
	int iPartId, int iStateId, LPCWSTR pszText, int iCharCount, DWORD dwTextFlags,
	DWORD dwTextFlags2, const RECT *pRect);
typedef HRESULT	(__stdcall *PFNGETTHEMEBACKGROUNDCONTENTRECT)(HTHEME hTheme,
	HDC hdc, int iPartId, int iStateId,
	const RECT *pBoundingRect,
	RECT *pContentRect);
typedef BOOL	(__stdcall *PFNISAPPTHEMED)();
typedef BOOL	(__stdcall *PFNISTHEMEACTIVE)();
typedef HTHEME	(__stdcall *PFNOPENTHEMEDATA)(HWND hwnd, LPCWSTR pszClassList);

/*!
*	@class		CP_ThemeSupport
*	@brief		Singleton class to provide support for Windows theme drawing.
*/
class CP_ThemeSupport
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_ThemeSupport();
	//! Destructor.
	virtual 							~CP_ThemeSupport();
	//@}

	//! @name Instance
	//@{
	static	CP_ThemeSupport				*Instance();
	//@}

	//! @name Attributes
	//@{
			BOOL						IsAppThemed();
			BOOL 						IsThemeActive();
			BOOL						IsThemeLibAvailable()						{ return( fThemeLibLoaded ); }
	//@}

	//! @name Operators
	//@{
			BOOL						CloseThemeData(HTHEME hTheme);
			BOOL						DrawThemeBackground(
												HTHEME hTheme,
												HDC hdc,
												int iPartId,
												int iStateId,
												const RECT *pRect,
												const RECT *pClipRect );
			BOOL						DrawThemeText(
												HTHEME hTheme,
								  				HDC hdc,
						  						int iPartId,
						  						int iStateId,
						 				 		LPCTSTR lpszText,
												DWORD dwTextFlags,
												DWORD dwTextFlags2,
												const RECT *pRect );
			BOOL						GetThemeBackgroundContentRect(
												HTHEME hTheme,
												HDC hdc,
										  		int iPartId,
										  		int iStateId,
										  		const RECT *pBoundingRect,
										  		RECT *pContentRect );
			HTHEME						OpenThemeData(
												HWND hWnd,
												LPCTSTR lpszClassList );
	//@}

private:
	//! @name Initialization
	//@{
			void						Init();
	//@}

	// class data
private:
	static CP_ThemeSupport					*fsInstance;
	
	static PFNCLOSETHEMEDATA				fCloseThemeData;
	static PFNDRAWTHEMEBACKGROUND			fDrawThemeBackground;
	static PFNDRAWTHEMETEXT					fDrawThemeText;
	static PFNGETTHEMEBACKGROUNDCONTENTRECT	fGetThemeBackgroundContentRect;
	static PFNISAPPTHEMED					fIsAppThemed;
	static PFNISTHEMEACTIVE					fIsThemeActive;
	static PFNOPENTHEMEDATA					fOpenThemeData;

	static HMODULE							fThemeLib;
	static BOOL								fThemeLibLoaded;

	static int								fUseCount;
};
	
}	// namespace CP_Theme

CPLAT_End_Namespace_CPLAT

#endif  // TARGET_OS_WIN32 && CP_Optional_ThemeSupport_Windows

#endif	// _H_CP_ThemeSupport

